.TH XZAP 1 "Release 1.1" 
.SH NAME
xzap - X Process Zapper
.SH SYNTAX
\fBxzap\fP [ -toolkitoption ...] [ -xzapoption ...] [ ps options ]
.SH OPTIONS
.I Xzap
accepts all of the standard X Toolkit command line
options  (see \fIX(1)\fP), plus several xzap specific options
(see RESOURCES section below).
The [ ps options ] are those accepted by
the ps(1) command, these must come after any other options.
.SH DESCRIPTION
.I Xzap
provides an easy way to
to send signals to Unix processes, typically, but not necessarily,
to kill them.
It was inspired by the zap command described in Kernighan & Pike's
"The Unix Programming Environment". 
.PP
Xzap provides a window consisting of two areas:
.IP "Commands Section" 25
A set of command buttons that allow you to  exit, zap selected processes,
pop up an options menu,
pop up a help window, clear (deselect) processes, invoke a ps command.
.IP "Ps Output Window" 25
Displays the output from the ps command within a multilist
widget and allows processes 
to be selected with mouse button 1 ready for zapping with the zap command.
Clicking with button 1 on an already selected process  deselects it.
Clicking with button 3 "extends" the "closest" selection.
.SH COMMANDS
.IP "quit" 8
Quits  xzap.
.IP "zap" 8
Represented by a bitmap,
often the
"skull and crossbones".
zap delivers a signal to processes selected in the "Ps Output Window".
By default this is the TERM (terminate, 15) signal but it may be 
changed by use of the options menu. 
The terminate signal will kill processes that do not catch
the signal but sending KILL is a sure kill, as the KILL 
(9) signal cannot be caught.
.IP
A successfully delivered signal is indicated by the appropriate line
of ps output becoming insensitive.  
(This does not necessarily mean the process has been killed,
you must reinvoke ps to confirm this).
.IP "help"
Pops up a help window.
.IP "clear"
Deselects all selected processes in the "Ps Output Window".
.IP "ps"
Invokes a ps(1) command whose arguments are the contents of the neighbouring 
text widget (psoptions).
.SH ACCELERATORS
By default, accelerators are defined such that:

typing a <return> in the psoptions
text widget 
cause the ps command to be invoked,

typing anywhere
causes characters to be entered into the psoptions text widget (so
typing <return> anywhere causes the ps command to be invoked too),

hitting mouse button 2 in the "Ps Output Window" causes "zap" to be invoked,
but only if the zapAccelerator application resource is set.

.SH RESOURCES
\fIxzap\fP has the following application specific resources:
.TP 8
.B command  (\fPClass\fB Command)
An alternative command to run instead of ps.
.TP 8
.B defaultSignal (\fPClass\fB DefaultSignal)
Initial setting of the signal menu, hence the default signal sent when a
process is zapped (default 15 i.e SIGTERM).
.TP 8
.B pidColumn  (\fPClass\fB PidColumn)
A string defining the column contain the process ids (default "  PID").
.TP 8
.B psOnDeiconify  (\fPClass\fB PsOnDeiconify)
Causes a ps to be executed automatically when xzap is deiconifed,
useful in conjuction with the standard toolkit resource iconic,
(default false).
.TP 8
.B psOptionsList  (\fPClass\fB PsOptionsList)
Determines the content of the second section of the \fIoptions\fP menu.
Each line resource represents two strings separated by
\fI:\fP.  The first string of a pair is copied into the \fIpsoptions\fP
text widget when the menu item named by the second string is selected
from the \fIoptions\fP menu.
.TP 8
.B scrollHeight (\fPClass\fB ScrollHeight)
Xzap resizes its main window to display the output of each ps command
up to a height specified by the scrollHeight resource, at which point
it adds a scrollbar. Manual resizing has the effect of changing this
resource (default 300).
.TP 8
.B rootCursor (\fPClass\fB RootCursor)
Changes the cursor to indicate running as root (default "pirate") (on
pre-X11R5 systems you will always get "pirate" if this resource is
set).
.TP 8
.B rootTitleSuffix (\fPClass\fB RootTitleSuffix)
Appends to the title to indicate running as root (default " (root)"))
.TP 8
.B rootIconNameSuffix  (\fPClass\fB RootIconNameSuffix)
Appends to the icon name to indicate running as root  (default "
(root)" )
.TP 8
.B signalList   (\fPClass\fB SignalList)
An arbitary number of lines of the form number:bitmap:name. These
determine the content of the first section of the options menu. Each
number should represent a valid signal, xzap does not check this. The
bitmap is used to change the appearance of the "zap" command button
when a new signal is chosen, and the name is that displayed in the
menu. The name may contain any characters except \fI:\fP  (and
newline).
.TP 8
.B zapAccelerator (\fPClass\fB ZapAccelerator)
Installs an accelerator for the "zap" command button in the "Ps Output
Window", normally mouse button 2 (default false).
.PP
These resources can all be specified as command line options,
.br

eg. to use sps instead of ps invoke xzap as:
.br

xzap -command sps -pidColumn Proc#


A personal xzap resource file, called Xzap and normally
in your home directory, might contain the following to cater for both
ps and sps:
.nf

xsps.command:			/usr/local/bin/sps
xsps.pidColumn:			Proc#
xsps*ps.label:			sps
*.signalList:			\\
				1:hup.bm:SIGHUP\\n\\
				3:quit.bm:SIGQUIT\\n\\
				9:kill.bm:SIGKILL\\n\\
				15:term.bm:SIGTERM
xzap.psOptionsList:		\\
				aux:all\\n\\
				aux|sort -r -n +4 -5:sort all on size
xsps.psOptionsList:			\\
				AV:all processes\\n\\
				FV:foreground processes\\n\\
				AVd:disk activity
*zapAccelerator:		true
.fi
.PP
When invoked as xsps the sps relevant resources apply. This may be
achieved via the -name toolkit option i.e. xzap -name xsps.
.SH WIDGETS
In order to specify further resources, it is useful to know the hierarchy of
the widgets which compose \fIxzap\fR.  In the notation below,
indentation indicates hierarchical structure.  The widget class name
is given first, followed by the widget instance name.
.sp
.nf
.TA .5i 1.0i 1.5i 2.0i
.ta .5i 1.0i 1.5i 2.0i
Xzap xzap
	Form  form
        	Command  quit
		Command  zap
		MenuButton  options
			SimpleMenu optionsmenu
				SmeBSB  terminate
					.
					.
		Command  help
		Command  clear
		Command  ps
		Text  psoptions
		Viewport  viewport
			Form  form2
				Label  header
				Multilist  multilist
	TopLevelShell  helpshell
		Form  helpform
			Command  helpdismiss
			Text  helptext

For example:

Xzap*psoptions*string:  aux

would cause xzap to start up by executing "ps aux".

and

Xzap*Multilist.cursorName:  pirate

would force the use of the pirate cursor (but note the
cursorName resource does not exist pre X11R5).
.fi
.sp
.SH ENVIRONMENT
.PP
.TP 8
.B DISPLAY
to get the default host and display number.
.TP 8
.B XENVIRONMENT
to get the name of a resource file that overrides the global resources
stored in the RESOURCE_MANAGER property.
.SH FILES
/usr/lib/X11/app-defaults/Xzap - specifies required resources
.SH SEE ALSO
ps(1), X(1), xrdb(1), Athena Widget Set, FWF widget set
.SH RESTRICTIONS
Ps output is limited to 500 lines.
.br
Can't figure out whether output is really from a ps.
.br
Can deadlock if data produced on stderr not small.
.SH COPYRIGHT
Copyright 1993, The Computing Laboratory, University of Newcastle Upon Tyne 
.SH AUTHOR
Gerry Tomlinson (gerry.tomlinson@newcastle.ac.uk) 
.SH ACKNOWLEDGMENTS
Thanks to Brian Totty <totty@cs.uiuc.edu> for the Multilist widget
from the Free Widget Foundation widget set.
