/*
 * Copyright 1993 The University of Newcastle upon Tyne
 * 
 * Permission to use, copy, modify and distribute this software and its
 * documentation for any purpose other than its commercial exploitation
 * is hereby granted without fee, provided that the above copyright
 * notice appear in all copies and that both that copyright notice and
 * this permission notice appear in supporting documentation, and that
 * the name of The University of Newcastle upon Tyne not be used in
 * advertising or publicity pertaining to distribution of the software
 * without specific, written prior permission. The University of
 * Newcastle upon Tyne makes no representations about the suitability of
 * this software for any purpose. It is provided "as is" without express
 * or implied warranty.
 * 
 * THE UNIVERSITY OF NEWCASTLE UPON TYNE DISCLAIMS ALL WARRANTIES WITH
 * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL THE UNIVERSITY OF
 * NEWCASTLE UPON TYNE BE LIABLE FOR ANY SPECIAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF
 * USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 * 
 * Author:  Gerry Tomlinson (gerry.tomlinson@newcastle.ac.uk)
 *          Computing Laboratory, University of Newcastle upon Tyne, UK
 */

/*****************************************************************************

xzap.c

xzap using MultiList widget

Gerry.Tomlinson@newcastle.ac.uk
June 1993

****************************************************************************/

#include <X11/Xos.h>
#include <X11/Xatom.h>
#include <X11/cursorfont.h>
#include <X11/Xlib.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <X11/Xaw/Form.h>
#include <X11/Xaw/Box.h>
#include <X11/Xaw/Viewport.h>
#include <X11/Xaw/Command.h>
#include <X11/Xaw/Label.h>
#include <X11/Xaw/AsciiText.h>
#include <X11/Xaw/TextSink.h>
#include <X11/Xaw/MenuButton.h>
#include <X11/Xaw/SimpleMenu.h>
#include <X11/Xaw/Sme.h>
#include <X11/Xaw/SmeBSB.h>
#include <X11/Xaw/SmeLine.h>

#include "MultiList.h"

#include <stdio.h>
#include <signal.h>
#include <ctype.h>

#include "pirate.bm"
#include "tick.bm"

char *strtok();
#define max(a, b) ((a) > (b) ? (a) : (b))

/* global data to handle ps output */

#define MAXITEMS 500
char cmndbuf[BUFSIZ];	/* to hold ps command string			*/
char *lines[MAXITEMS]; /* to hold the ps output lines                  */  
char **processes = &lines[0]; /* first process data output line       */
char *psheader;
Boolean sens[MAXITEMS]; /* sensitivity array for multiList 		*/
Boolean selec[MAXITEMS]; /* selected array for multiList		*/
int maxline;		/* number of valid lines in the multiList	*/
int pidcol = -1;        /* char position of PID column			*/
int selpids [MAXITEMS];	/* to hold the  selected pids 	        	*/
int selpidscount;	/* number of selected pids 			*/

/* global X stuff */

typedef struct  _AppResources {
    int scrollHeight;
    String command;
    int defaultSignal;	
    String pidColumn;
    Boolean psOnDeiconify;
    String rootIconNameSuffix;
    String rootCursor;
    String rootTitleSuffix;
    String signalList;
    String psOptionsList;
    Boolean zapAccelerator;
/* the following are here for convenience - really belong to app shell */
    String title;
    String iconName;
} AppResources;	

AppResources app_resources;


static XtResource resources[] = {
    {"defaultSignal", "DefaultSignal", XtRInt, sizeof(int),
    XtOffset(AppResources *, defaultSignal), XtRImmediate, (XtPointer)SIGTERM
    },
    {"scrollHeight", "ScrollHeight", XtRInt, sizeof (int),
    XtOffset(AppResources *, scrollHeight), XtRImmediate, (XtPointer)300
    },
    {"command", "Command", XtRString, sizeof(String),
    XtOffset(AppResources *, command), XtRImmediate, (XtPointer) "/bin/ps"
    },
    {"pidColumn", "PidColumn", XtRString, sizeof(String),
    XtOffset(AppResources *, pidColumn), XtRImmediate, (XtPointer) "  PID"
    },
    {"psOnDeiconify", "PsOnDeiconify", XtRBoolean, sizeof(Boolean),
    XtOffset(AppResources *, psOnDeiconify), XtRImmediate, (XtPointer) FALSE
    },
    {"rootIconNameSuffix", "SetrootIconNameSuffix", XtRString, sizeof(String),
    XtOffset(AppResources *, rootIconNameSuffix), 
		XtRImmediate, (XtPointer)" (root)"
    },
    {"rootTitleSuffix", "RootTitleSuffix", XtRString, sizeof (String),
     XtOffset(AppResources *, rootTitleSuffix),
		XtRImmediate, (XtPointer)" (root)"
    },
    {"rootCursor", "RootCursor", XtRString, sizeof (String),
     XtOffset(AppResources *, rootCursor),
		 XtRImmediate, (XtPointer) "pirate"
    },
    {"signalList","SignalList", XtRString, sizeof (String),
     XtOffset(AppResources *, signalList),
		XtRImmediate, (XtPointer) "15:term.bm:terminate \n\
					    9:kill.bm:kill"
    },
    {"psOptionsList","PsOptionsList", XtRString, sizeof (String),
     XtOffset(AppResources *, psOptionsList),
		XtRImmediate, (XtPointer) "all:aux"
    },
    {"zapAccelerator", "ZapAccelerator", XtRBoolean, sizeof(Boolean),
    XtOffset(AppResources *, zapAccelerator),
		XtRImmediate, (XtPointer) FALSE
    },
};

static XrmOptionDescRec optiondesc[] = {
{"-scrollHeight", "scrollHeight", XrmoptionSepArg,        NULL},
{"-command", "command", XrmoptionSepArg,        NULL},
{"-defaultSignal", "defaultSignal", XrmoptionSepArg,        NULL},
{"-pidColumn", "pidColumn", XrmoptionSepArg,        NULL},
{"-psOnDeiconify", "psOnDeiconify", XrmoptionNoArg, (XtPointer)"on"},
{"-rootCursor","rootCursor", XrmoptionSepArg, NULL}, 
{"-rootIconNameSuffix","rootIconNameSuffix",XrmoptionSepArg,  NULL},
{"-rootTitleSuffix","rootTitleSuffix", XrmoptionSepArg, NULL},
{"-signalList","signalList", XrmoptionSepArg, NULL},
{"-psOptionsList","psOptionsList", XrmoptionSepArg, NULL},
{"-zapAccelerator","zapAccelerator", XrmoptionNoArg, (XtPointer)"on"}
};

static char xzapTranslations[] =
    "<MapNotify>:	Ps()";

XtAppContext app_con;
Display *display;
static Pixmap tick;
static Cursor busycursor, mlcursor;

typedef struct _Signalmenu {
   char* name; char * bitmap; int value;}
Signalmenu ;

Signalmenu* signalmenu;

typedef struct _Psoptionsmenu {
   char* name; char * value;}
Psoptionsmenu ;

Psoptionsmenu* psoptionsmenu;


static Widget current_signal_item;
static int current_signal;

Dimension maxvpheight;


/* local routines */

strindex(s,t) /* return index of t in s, -1 if none */
   char *s, *t;
{
    int i, n;

    n = strlen(t);
    for (i = 0; s[i] != '\0'; i++)
	if (strncmp(s+i, t, n) == 0)
	    return i;
    return -1;
}

Boolean
getpsinfo() 

/*
 * do a ps & return number of lines - putting them into
 * strings array and update maxline and pidcol.
 * return TRUE  if we find a ps header or get some other output
 *
 * we may block in fgets(), really need to be a bit cleverer
 */

{
        int newpidcol = -1;
	int i = 0;
 
	FILE *fin, *popen();

        char buf[BUFSIZ];



	if ((fin = popen(cmndbuf,"r")) == NULL) {
                fprintf(stderr,"xzap: can't run %s\n",cmndbuf);
                exit(1);
        }

        while (fgets(buf, sizeof buf, fin) != NULL) {     
                buf[strlen(buf)-1] = '\0';
		if (newpidcol == -1) {
		    newpidcol = strindex(buf,app_resources.pidColumn);
		    if (newpidcol != -1)  {
		  	XtFree(psheader);
			psheader = XtNewString(buf);
			continue;
		    }
		}
		XtFree(lines[i]);	/* always free old string first */
		lines[i] = XtNewString(buf);
		if (++i == MAXITEMS) break;
            }

	pclose(fin);
	
	if (newpidcol != -1) pidcol = newpidcol;

	if ( i > 0 || ( newpidcol != -1)) {
		 maxline = i; 
		 return TRUE;
	}
	else	return FALSE;
 
 }

               
/*
 * checkroot
 *
 */

void
checkroot(top,target)
Widget top, target;
{
   char iconname[200];
   char title[200];

   if (geteuid() == 0) {
	iconname[0] =  title[0] = '\0';
	sprintf(iconname,"%s%s",app_resources.iconName,
				app_resources.rootIconNameSuffix);
	sprintf(title,"%s%s",app_resources.title,
				app_resources.rootTitleSuffix);


        XtVaSetValues(top,XtNiconName,iconname,
        		 XtNtitle,title, 
			 NULL);

	if (app_resources.rootCursor) {
#if XtSpecificationRelease < 5
	    Cursor piratecursor;
	    piratecursor = XCreateFontCursor(display, XC_pirate);
	    XtVaSetValues(target,XtNcursor, piratecursor, NULL);
#else
	    XtVaSetValues(target,XtNcursorName, app_resources.rootCursor,
			NULL);
#endif
	}
  }
}

	
/* declare callbacks & work procs */
void Quit(), SetSignal(), Zap(), Clearall(), Help(), Ps(), Dismiss(), ErrorDismiss (), SetPsOption();
void PsWorkAction();
Boolean Pswork();

static XtActionsRec actionTable[] =
{
    {"Quit", Quit},
    {"Ps", PsWorkAction},
};

static String transtable =
	"<ClientMessage>WM_PROTOCOLS: Quit()\n";

static Widget top,form,quit,zap,options,optionsmenu,help,clear,ps,psoptions,viewport,header,multiList,helpshell,helpform,helptext,helpdismiss,errorshell;

void
fixheights()
/*
 * adjust the heights of the widgets inside form to allow for odd height
 * of any  bitmaps
 *
 */

{
    Dimension maxheight,optionsheight,quitheight,zapheight,clearheight,helpheight,
                        psheight,psoptionsheight;

    XtVaGetValues(quit, XtNheight, &quitheight, NULL);
    maxheight = quitheight;

    XtVaGetValues(zap, XtNheight, &zapheight, NULL);
    maxheight = (zapheight  > maxheight ? zapheight : maxheight);

    XtVaGetValues(options, XtNheight, &optionsheight, NULL);
    maxheight = (optionsheight  > maxheight ? optionsheight : maxheight);

    XtVaGetValues(clear, XtNheight, &clearheight, NULL);
    maxheight = (clearheight  > maxheight ? clearheight  : maxheight);	

    XtVaGetValues(help, XtNheight, &helpheight, NULL);
    maxheight = (helpheight  > maxheight ? helpheight  : maxheight);

    XtVaGetValues(ps, XtNheight, &psheight, NULL);
    maxheight = (psheight  > maxheight ? psheight  : maxheight);

    XtVaGetValues(psoptions, XtNheight, &psoptionsheight, NULL);
     maxheight = (psoptionsheight  > maxheight ? psoptionsheight  : maxheight);

    XtVaSetValues(quit,XtNheight,maxheight,NULL);	
    XtVaSetValues(zap,XtNheight,maxheight,NULL);
    XtVaSetValues(options,XtNheight,maxheight,NULL);
    XtVaSetValues(clear,XtNheight,maxheight,NULL);
    XtVaSetValues(help,XtNheight,maxheight,NULL);
    XtVaSetValues(ps,XtNheight,maxheight,NULL);
    XtVaSetValues(psoptions,XtNheight,maxheight,NULL);
}

/*
 * 
 * Do_stderr
 *
 * callback when data ready on stderr
 *
 * we assume a small amount of data and put it in a popup shell
 * if there is more then users sees that last chunk,
 * but if there is more than a pipe buffer full we'll never get
 * here as we'll have hung in read on stdin following popen()
 *
 */
void Do_stderr(client_data, source, id)
    XtPointer client_data;
    int source;
    XtInputId *id;
{
    int fd = (int)client_data;
    char buf [512];
    int n;

    static Widget errorform,errorlabel,errordismiss;
    Dimension width, height, b_width;
    Position x, y, inside_y, max_x, max_y;
    Window root_return, child_return;
    int root_x_return, root_y_return;
    int win_x_return, win_y_return;
    unsigned int mask_return;

    n = read(fd, buf, 512);
    buf[n] = 0;

    if (!n) return;

    XBell(display,0);


    if (errorshell == NULL){
	errorshell = XtVaCreatePopupShell("errorshell",
                                transientShellWidgetClass,top,NULL);

	errorform = XtVaCreateManagedWidget("errorform",
				formWidgetClass,errorshell,
				NULL);

        errorlabel = XtVaCreateManagedWidget("errorlabel",
				labelWidgetClass, errorform,
				NULL);
        errordismiss = XtVaCreateManagedWidget("errordismiss",
				commandWidgetClass, errorform,
				NULL);
        XtAddCallback (errordismiss,XtNcallback, ErrorDismiss, NULL);
	XtInstallAccelerators(errorform,errordismiss);
    }

    XtVaSetValues(errorlabel,XtNlabel,buf,NULL);

    XQueryPointer(display,XtWindow(top),&root_return,&child_return,
			 &root_x_return, &root_y_return,
			 &win_x_return, &win_y_return, &mask_return);

    x = (Position) root_x_return;
    y = (Position) root_y_return;

    XtVaGetValues(errordismiss,
		  XtNwidth, &width,
		  XtNheight, &height,
		  XtNy, &inside_y,
		  XtNborderWidth, &b_width,
		  NULL);

    width += 2 * b_width;
    inside_y+= 2 * b_width;

    x -= ( (Position) width/2 );
    if (x < 0) x = 0;

   if (x > (max_x = (Position) (XtScreen(errorshell)->width - width))) x = max_x;
    
    y -=  (Position) (height/2 + inside_y );
    if (y < 0) y = 0;
    if (y > (max_y = (Position) (XtScreen(errorshell)->height - height))) y = max_y;

    XtVaSetValues(errorshell,
		  XtNx, x,
		  XtNy, y,
		  NULL);


    XtPopup(errorshell,XtGrabExclusive);

}



makemenuitems()
/*
 * make menu items from signalList and psOptionsList resources
 * use defaultSignal to set initial signal i.e. current_signal
 *
 */
{
	
	Widget entry;
	int i;
  	int n ;
	char *s;

        s = app_resources.signalList;
	n = 0;
	if (*s)  n++;
        while  (*s) {
	    if (*s == '\n') {
		 *s = 0;
		 n++;
	     }
	     s++;
	};
	if (!*--s) n--;

	if (n == 0 )
	    current_signal = app_resources.defaultSignal;
	else {	

        signalmenu = (Signalmenu *) malloc(sizeof(Signalmenu) * n);
	s = app_resources.signalList;

        for (i = 0; i < n; i++) {	 
             sscanf(s,"%d", &signalmenu[i].value); 	/* get the signal */
	     while(*s && *s++ != ':');	     		/* skip signal */
 	     signalmenu[i].bitmap = s;	 		/* get the bitmap */
	     while(*s && *s++ != ':' );			/* skip bitmap */
	     *(s-1) = 0;
	     signalmenu[i].name = s;			/* set the name */
	     while (*s++);
	}		

        for (i = 0; i < n; i++) {	

	         entry = XtVaCreateManagedWidget(signalmenu[i].name,smeBSBObjectClass,
				optionsmenu,
			 	NULL);
		if (!current_signal) {
	   		 current_signal = signalmenu[i].value;
			 current_signal_item = entry;
		}
	        if ( app_resources.defaultSignal == signalmenu[i].value ) { 
		    XtVaSetValues(entry,XtNleftBitmap,tick,NULL);
	            current_signal_item = entry;
	  	    current_signal = signalmenu[i].value;
	        }

	        XtAddCallback(entry,XtNcallback,SetSignal,(XtPointer)i);
	 }

	}
	
	

        s = app_resources.psOptionsList;
	if (n && s)
	    XtVaCreateManagedWidget("line",smeLineObjectClass,
						optionsmenu, NULL);
 
	n = 0;
        if (*s)  n++;
        while  (*s) {
	    if (*s == '\n') {
		 *s = 0;
		 n++;
	     }
	     s++;
	};
	if (!*--s) n--;

        psoptionsmenu = (Psoptionsmenu *) malloc(sizeof(Psoptionsmenu) * n);
	s = app_resources.psOptionsList;

       for (i = 0; i < n; i++) {
	     while(isspace(*s)) s++;	 
 	     psoptionsmenu[i].value = s;	 	
	     while(*s && *s++ != ':' );		
	     *(s-1) = 0;
	     psoptionsmenu[i].name = s;		
	     while (*s++);
	}		

        for (i = 0; i < n; i++) {	

	         entry = XtVaCreateManagedWidget(psoptionsmenu[i].name,
				smeBSBObjectClass,
				optionsmenu,
			 	NULL);

	    XtAddCallback(entry,XtNcallback,SetPsOption,(XtPointer)i);
	    }

	}



main(argc,argv)
int argc;
char **argv;
/*
 * note don't map top until we've done the inital ps 
 *
 */
{

	Pixmap zappixmap;


        top = XtVaAppInitialize(&app_con,"Xzap",
				optiondesc,XtNumber(optiondesc),
				&argc,argv,NULL,
				XtNallowShellResize, TRUE,
				XtNmappedWhenManaged, FALSE,
                                NULL);

	display = XtDisplay(top);

	XtGetApplicationResources(top, (XtPointer) &app_resources, resources,
				XtNumber(resources), NULL, 0);

	XtVaGetValues(top,XtNiconName, &app_resources.iconName,
				XtNtitle, &app_resources.title,
				NULL);

	tick = 	XCreateBitmapFromData(display,
		RootWindow(display, DefaultScreen(display)),
		tick_bits, tick_width, tick_height);

        form = XtVaCreateManagedWidget("form",formWidgetClass,top,
				XtNdefaultDistance,2,
				NULL);


	quit =  XtVaCreateManagedWidget ("quit", commandWidgetClass,form,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
                                NULL);
 
        zap = XtVaCreateManagedWidget ("zap", commandWidgetClass,form,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
				XtNfromHoriz, quit,
                                NULL);

	XtVaGetValues(zap,XtNbitmap,&zappixmap,NULL);
        if (zappixmap == None)
		 zappixmap = XCreateBitmapFromData(XtDisplay(top), 
		         RootWindow(display, DefaultScreen(display)),
			 pirate_bits, pirate_width, pirate_height);
	XtVaSetValues(zap,XtNbitmap,zappixmap,NULL);

	options = XtVaCreateManagedWidget ("options",menuButtonWidgetClass,form,
				XtNmenuName,"optionsmenu",
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
                                XtNfromHoriz, zap,
                                NULL);

	optionsmenu = XtVaCreatePopupShell("optionsmenu",simpleMenuWidgetClass,
					 options,
					NULL);

        makemenuitems();

        help = XtVaCreateManagedWidget ("help", commandWidgetClass,form,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
                                XtNfromHoriz, options,
                                NULL);



        clear = XtVaCreateManagedWidget ("clear", commandWidgetClass,form,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
                                XtNfromHoriz, help,
                                NULL);

	ps = XtVaCreateManagedWidget ("ps",commandWidgetClass,form,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
                  		XtNfromHoriz,clear,
				NULL);

	psoptions =  XtVaCreateManagedWidget ("psoptions", asciiTextWidgetClass,
								form,
				XtNfromHoriz,ps,
				XtNleft, XtChainLeft,
				XtNright, XtChainRight,
				XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
				XtNeditType,XawtextEdit,
				XtNresize, XawtextResizeWidth,
				XtNresizable,TRUE,
				NULL);


        if (argc >1) XtVaSetValues(psoptions,XtNstring,argv[1],NULL);

	header = XtVaCreateManagedWidget("header",labelWidgetClass,form,
				XtNfromVert, quit,
				XtNresizable,TRUE,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
				XtNjustify,XtJustifyLeft,
				XtNlabel, "",
				XtNborderWidth,0,
				NULL);

	viewport = XtVaCreateManagedWidget("viewport",viewportWidgetClass,form,
				XtNfromVert,header,
				XtNborderWidth,1,
				XtNleft, XtChainLeft,
				XtNright, XtChainRight,
				XtNtop, XtChainTop,
				XtNbottom,XtChainBottom,
				XtNvertDistance,0,
				XtNresizable,TRUE,
				XtNmappedWhenManaged, FALSE,
                                NULL);



        multiList = XtVaCreateManagedWidget("multiList",
                                             multiListWidgetClass,viewport,
				XtNresizable,TRUE,
                                XtNlist,&lines[1],
                                XtNforceColumns,TRUE,
                                XtNborderWidth,0,
                                XtNmaxSelectable,MAXITEMS,
				XtNfromVert,header,
                                XtNleft, XtChainLeft,
                                XtNright, XtChainRight  ,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
                                NULL);

        helpshell = XtVaCreatePopupShell("helpshell",
				topLevelShellWidgetClass,top,NULL);

	helpform = XtVaCreateManagedWidget("helpform",
				formWidgetClass,helpshell,
				NULL);

        helpdismiss  = XtVaCreateManagedWidget("helpdismiss",
				commandWidgetClass,helpform,
				XtNleft, XtChainLeft,
                                XtNright, XtChainLeft,
                                XtNtop, XtChainTop,
                                XtNbottom, XtChainTop,
				NULL);
			
	helptext = XtVaCreateManagedWidget("helptext",
				asciiTextWidgetClass,helpform,
				XtNfromVert,helpdismiss,
				XtNtop,XtChainTop,
				XtNleft, XtChainLeft,
				XtNstring, access(HELPFILE,R_OK) == 0 ?
						HELPFILE : "xzap.help",
				NULL);
	fixheights();

	XtAddCallback(quit,XtNcallback,Quit,NULL);
        XtAddCallback(zap,XtNcallback,Zap,multiList);
        XtAddCallback(ps,XtNcallback,Ps,multiList);
        XtAddCallback(help,XtNcallback,Help,helpshell);
        XtAddCallback(clear,XtNcallback,Clearall,multiList);
	XtAddCallback(helpdismiss,XtNcallback,Dismiss,helpshell);

	XtAppAddActions(app_con, actionTable, XtNumber(actionTable));
	XtOverrideTranslations(top, XtParseTranslationTable(transtable));

	XtInstallAccelerators(psoptions,ps);
        if (app_resources.zapAccelerator)
	    XtInstallAccelerators(multiList,zap);
	XtSetKeyboardFocus(form,psoptions);

        XtRealizeWidget(top);

	checkroot(top,multiList);

	{
	Dimension topheight, vpheight;
	  XtVaGetValues(top,XtNheight, &topheight, NULL);
	  XtVaGetValues(viewport, XtNheight, &vpheight, NULL);
	  maxvpheight = app_resources.scrollHeight - (topheight - vpheight);
	}

	busycursor  = XCreateFontCursor(display, XC_watch);
	XtVaGetValues(multiList, XtNcursor, &mlcursor,NULL);

	if (!app_resources.psOnDeiconify)
	    (void) Pswork((XtPointer)NULL);
	else
	    XtOverrideTranslations(top,XtParseTranslationTable(xzapTranslations));

	{
	Atom wm_delete_window;
	    wm_delete_window = XInternAtom (display, "WM_DELETE_WINDOW", False);
	    XSetWMProtocols(display,XtWindow(top),&wm_delete_window, 1);
	}

	
	XtMapWidget(top);

#ifndef macII
	{

/*
 *	arrange for stderr to be captured by this process
 *	works nicely for intended usage  - eg stderr output when
 *	user puts in bad args to ps etc. - but can be defeated by large
 *	(> pipe buffer) amount of output in which case we'll hang
 *	following  popen() 
 * 	for some reason A/UX  doesn't like this
 */
	int stderr_pipe[2];
	pipe(stderr_pipe);
	dup2(stderr_pipe[1],2);
	XtAppAddInput(app_con,stderr_pipe[0],(XtPointer)XtInputReadMask, Do_stderr,(XtPointer)stderr_pipe[0]);
	}
#endif


        XtAppMainLoop(app_con);

} /* End main */

/*ARGSUSED*/
void 
Quit(w,client_data,call_data)
Widget w;
XtPointer client_data,call_data;
{
	exit(0);
}

/*
 * Zap
 * 
 * callback/action routine 
 * kill processes indicated by highlit items in multilist widget
 * set item insensitive if signal delivered successfully
 * else leave selected - this is very contorted as we have to
 * reselect the failed items.
 * Also record pid in selpids if successful so this pid will be reselected
 * after subsequent ps if it is still around.
 */
/*ARGSUSED*/
void
Zap(w,client_data,call_data)
Widget w;
XtPointer client_data,call_data;
{
        Widget ml = (Widget) client_data;
        int i,pid;
        String str_ptr;
        Boolean *h_ptr,*s_ptr;

	MultiListReturnStruct *rs;


	for (i = 0 ; i < maxline; i++) selec[i] = FALSE; 

        rs = MultiListGetHighlighted(ml);

        for (i = 0; i < rs->num_selected; i++)
        {
		MultiListGetItemInfo(ml,rs->selected_items[i],&str_ptr,&h_ptr,&s_ptr);
                if (sscanf(&str_ptr[pidcol],"%d",&pid) != 1)   {
		    fprintf(stderr,"xzap: problem in parsing pid %s\n",&str_ptr[pidcol]);
		    break;
		} 
		if (pid > 0 && kill(pid, current_signal) == 0 ) {
		    sens[rs->selected_items[i]] = FALSE;
		    selpids[selpidscount++] = pid;
		} 
		else {
		    XBell(display,0);
		    selec[rs->selected_items[i]] = TRUE;
		}
	}

	MultiListSetNewData(ml,processes,maxline,0,TRUE,sens);
	
	for (i = 0 ; i < maxline; i++) 
	    if (selec[i]) MultiListHighlightItem(ml,i);
}


/*ARGSUSED*/
void
Ps(w,client_data,call_data)
Widget w;
XtPointer client_data,call_data;
/*
 * the ps callback - just register a work proc so as not block
 * this causes the set() action routine to be have effect before
 * the ps is done - & leaves the  work proc to do the unset()
 *
 */
{
        XtAppAddWorkProc(app_con,Pswork,NULL);
}

/*ARGSUSED*/
void
PsWorkAction(w, event,params,num_params)
Widget w;
XEvent *event;
String *params;
Cardinal num_params;
{
   (void)Pswork((XtPointer)NULL); 
}

/*ARGSUSED*/
Boolean
Pswork(client_data)
XtPointer client_data;
/*
 * the work proc called indirectly by the ps call back,
 * actually does the ps & blocks whilst reading its 
 * results from a pipe - this is an indefinite block since
 * the user may apply an arbitary pipeline command, so
 * at the end we call the ps unset() action routine then  return
 * true to cause the work proc to be automatically removed.
 *
 */
{
	String psopts;
	Boolean success;
	int i,j;
        static Dimension vpheight,mlheight;
	Dimension viewportwidth,verticalwidth,psoptionswidth;
	Boolean scrollbar;
	Widget vertical,textsink;
        static Dimension minpsoptionswidth = 99999;
	Position psoptionsxvalue;
	int horizDistance;

        XRectangle eofplace;
        MultiListReturnStruct *rs;
	String str_ptr;
        Boolean *h_ptr,*s_ptr;

/* first set cursor */

	XtVaSetValues(multiList, XtNcursor, busycursor, NULL);
	XFlush(display);

/* now record selected pids */
 
        rs = MultiListGetHighlighted(multiList);
	for (i = 0; i < rs->num_selected; i++)
        {
	    MultiListGetItemInfo(multiList,rs->selected_items[i],&str_ptr,&h_ptr,&s_ptr);
	    if (sscanf(&str_ptr[pidcol],"%d",&selpids[selpidscount]) != 1)  
		    fprintf(stderr,"xzap: problem in parsing pid %s\n",&str_ptr[pidcol]);
		    else selpidscount++;	    
   	}

/*
 * now prepare to do ps 
 *
 * we check whether there's a scrollbar on and if so set the maximum
 * height for the viewport to its current height 
 * so if the ps results in a scrollbar being added it's at same
 * position it was the last time
 * if scrollbar isn't on then we disable the vertical scroll bar resource
 * to allow the viewport to grow - then chop it back if necessary
 */

	if (vpheight)  {		/* no adjustment 1st time */
		XtVaGetValues(viewport,XtNheight,&vpheight,NULL);   
		XtVaGetValues(multiList,XtNheight,&mlheight,NULL);  
		if (mlheight > vpheight)  {  
		   scrollbar = TRUE;
		   maxvpheight = vpheight; 
		} else {
		   scrollbar = FALSE; 
		   maxvpheight = max(maxvpheight, vpheight);
		} 
	} 

	 if (!scrollbar) XtVaSetValues(viewport,XtNallowVert,FALSE,NULL);

	XtVaGetValues(psoptions,
                      XtNstring, &psopts,
		      XtNwidth,&psoptionswidth,
		      XtNtextSink,&textsink,
                      NULL);
/*        
 * fix options width to just hold text or reasonable minimum, we will
 * expand it later, 
 * first  moving the cursor to the far right i.e end of file
 */

	if (psoptionswidth < minpsoptionswidth) minpsoptionswidth = psoptionswidth;
	XtCallActionProc(psoptions,"end-of-file",NULL,NULL,0);
        XawTextSinkGetCursorBounds(textsink,&eofplace);
        XtVaSetValues(psoptions, XtNwidth,
	    (eofplace.x+10)>minpsoptionswidth
             ?eofplace.x+10:minpsoptionswidth,NULL);

        sprintf(cmndbuf,"%s %s",app_resources.command, psopts);

	success = getpsinfo();


      	if (success)   XtUnmapWidget(viewport);  

/*
 *	first set ps header regardless of outcome of ps - so
 *	we'll get old one if there was no header - this is
 * 	ok - 'cos  if there was no output and no header
 *	then old header is valid
 */
	XtVaSetValues(header, XtNlabel, psheader, NULL);

/*
 * put the ps output in the multilist widget - selecting those entries whose
 * pids match those recorded in selpids[]
 */		
   	if (success) {
       
	    for (i = 0 ; i < maxline; i++) sens[i] = TRUE;

            MultiListSetNewData(multiList,maxline?processes:NULL,maxline,0,TRUE,sens);
	
	    for (i = 0 ; i < maxline; i++) 
	    		for (j = 0; j < selpidscount; j++ )
	    		    if (atoi(&processes[i][pidcol]) == selpids[j])
		    	          MultiListHighlightItem(multiList,i);
	    selpidscount = 0;
	}

/*
 * now adjust height of viewport
 */
	XtVaSetValues(viewport,XtNallowVert,TRUE,NULL);
	
	XtVaGetValues(viewport,XtNheight,&vpheight,NULL);

	if (vpheight >= maxvpheight)
	{
	    XtVaGetValues(viewport,XtNwidth,&viewportwidth,NULL);
	    XtVaSetValues(viewport,XtNheight,maxvpheight,NULL);

	    vertical = XtNameToWidget(viewport,"vertical");
	    if (vertical == NULL) {printf("null vertical\n"); exit(1);}
	    XtVaGetValues(vertical,XtNwidth,&verticalwidth,NULL);
	    XtVaSetValues(viewport,XtNwidth,viewportwidth+verticalwidth,NULL);
	    XtVaSetValues(header,XtNhorizDistance,verticalwidth+4,NULL);	
	}
	else XtVaSetValues(header,XtNhorizDistance,2,NULL);

        XtVaGetValues(psoptions, XtNwidth,&psoptionswidth,
				 XtNx ,&psoptionsxvalue,
				 NULL);
        XtVaGetValues(viewport, XtNwidth,&viewportwidth,NULL);

/*
 * now force right edge of psoptions and viewport to align
 *
 */	
 	if  (psoptionsxvalue + psoptionswidth > viewportwidth )
	    XtVaSetValues(viewport, XtNwidth, psoptionsxvalue + psoptionswidth-2,NULL);
	else XtVaSetValues(psoptions, XtNwidth, viewportwidth + 2 - psoptionsxvalue, NULL);
	    
	XtMapWidget(viewport); 

	XtCallActionProc(ps,"unset",NULL,NULL,0);

	XtVaSetValues(multiList, XtNcursor, mlcursor, NULL);
	XFlush(display);

        return TRUE;

}

/*ARGSUSED*/
void 
Clearall(w,client_data,call_data)
Widget w;
XtPointer client_data,call_data;
{
	MultiListUnhighlightAll((Widget)client_data);
}

/*ARGSUSED*/
void 
Help(w,client_data,call_data)
Widget w;
XtPointer client_data,call_data;
{
        XtPopup((Widget)client_data,XtGrabNone);
}

/*ARGSUSED*/
void
Dismiss(w,client_data, call_data)
Widget w;
XtPointer client_data,call_data;
{
	XtPopdown((Widget)client_data);
}

/*ARGSUSED*/
void
ErrorDismiss(widget,w,client_data)
Widget w,widget;
caddr_t client_data;
{
    XtPopdown(errorshell);
}



/*ARGSUSED*/
void
SetSignal(w,client_data, call_data)
Widget w;
XtPointer client_data,call_data;
{
	int i = (int) client_data;

	if (signalmenu[i].value) {
		XtVaSetValues(current_signal_item, XtNleftBitmap, None, NULL);
		XtVaSetValues(w, XtNleftBitmap, tick, NULL);
		XtVaSetValues(zap, XtVaTypedArg, XtNbitmap, XtRString,
		     signalmenu[i].bitmap, strlen(signalmenu[i].bitmap) + 1, NULL);
		current_signal_item = w;
		current_signal = signalmenu[i].value;
	} 
}


/*ARGSUSED*/
void
SetPsOption(w,client_data, call_data)
Widget w;
XtPointer client_data,call_data;
{
	int i = (int) client_data;
	
	XtVaSetValues(psoptions, XtNstring, psoptionsmenu[i].value, NULL);
	XtCallActionProc(psoptions,"end-of-file",NULL,NULL,0);
}

